package com.dhcc.finance.main.service;

import java.util.List;

import com.dhcc.common.model.CurrencyMeta;
import com.dhcc.common.model.response.RestfulResponse;
import com.dhcc.finance.main.domain.CwGlTransfer;
import com.dhcc.finance.main.model.CwGlTransferAndSubjectName;
import com.dhcc.finance.main.model.CwGlTransferLike;
import com.github.pagehelper.PageInfo;



public interface CwGlTransferService {

	RestfulResponse<List<CwGlTransfer>, CurrencyMeta> searchCwGlTranser();

	RestfulResponse<Object, CurrencyMeta> deleteCwGlTransfer(String pkTransfer);

	RestfulResponse<Object, CurrencyMeta> addCwGlTransfer(CwGlTransfer cwGlTransfer);

	RestfulResponse<Object, CurrencyMeta> updateCwGlTransfer(CwGlTransfer cwGlTransfer);

	RestfulResponse<PageInfo<CwGlTransfer>, CurrencyMeta> searchCwGlTransferByNameLike(CwGlTransferLike cwGlTransferLike, int pageNum,
			int pageSize, int navigatePages);

	/**
	 * @param cwGlTransferLike
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @return RestfulResponse<PageInfo<CwGlTransferAndSubjectName>,CurrencyMeta>
	 *@author huangpeng
	 *@date 2019年3月29日 下午3:34:48
	 *@修改日志：
	 */
	RestfulResponse<PageInfo<CwGlTransferAndSubjectName>, CurrencyMeta> searchTransferAndSubjscheme(
			CwGlTransferLike cwGlTransferLike, int pageNum, int pageSize, int navigatePages);
	/**
	 * 功能描述  查询正在启用的结转方案
	 * @return RestfulResponse<List<CwGlTransfer>,CurrencyMeta>
	 * @author huangpeng
	 * @date 2019年7月11日 上午11:25:15
	 * 修改日志
	 */
	RestfulResponse<List<CwGlTransfer>, CurrencyMeta> selectAllForEnablestate();

}
